powered by
Exports sample image files to R temporary directory and returns a path to the sample image files. This function is only used in the example of run.ij.
run.ij
eximg()
Jpeg files to the R temporary directory and a path to the sample image files.
run.ij which this function wraps