Learn R Programming

LeafArea (version 0.1.8)

find.ij: Checking a path to ImageJ

Description

Check if ImageJ is installed in the correct directory.

Usage

find.ij(ostype = .Platform$OS.type)

Arguments

ostype

the Operating system types.

Value

A path for ImageJ application. On unix this will always be "/Applications/ImageJ/". On Windows this will always be "C:\Program Files\ImageJ\".

Details

When ImageJ, including ij.jar and Java, is not installed in the common location, users need to specify the path to ImageJ in run.ij.